#ifndef _PyMOL_VERSION
#ifndef PYMOL_EVAL
#define _PyMOL_VERSION "1.1r2pre"
#else
#define _PyMOL_VERSION "1.1eval"
#endif
#endif

#ifndef _PYMOL_1_x
#define _PYMOL_1_x
#endif

#ifndef _PyMOL_VERSION_double
#define _PyMOL_VERSION_double 1.10
#endif

/* for session file compatibility */

#ifndef _PyMOL_VERSION_int 
#define _PyMOL_VERSION_int 110
#endif



